(this.webpackJsonpstreamlit_component_template=this.webpackJsonpstreamlit_component_template||[]).push([[0],{13:function(e,t,n){e.exports={poCheckboxLabel:"style_poCheckboxLabel__2IHB4",poCheckboxSpan:"style_poCheckboxSpan__ltXcy",poCheckbox:"style_poCheckbox__3Q56z"}},18:function(e,t,n){e.exports=n(26)},26:function(e,t,n){"use strict";n.r(t);var o=n(8),a=n.n(o),c=n(16),s=n.n(c),r=n(6),i=n(0),p=n(1),u=n(2),l=n(3),d=n(14),b=n(13),h=n.n(b),m=function(e){Object(u.a)(n,e);var t=Object(l.a)(n);function n(){var e;Object(p.a)(this,n);for(var o=arguments.length,c=new Array(o),s=0;s<o;s++)c[s]=arguments[s];return(e=t.call.apply(t,[this].concat(c))).state={action:"",data:"",uniqueId:"",options:{layer:"",units:""},isFocused:!1,isChecked:!1},e.render=function(){return a.a.createElement("label",{className:h.a.poCheckboxLabel},a.a.createElement("input",{className:h.a.poCheckbox,type:"checkbox",defaultChecked:e.props.args.isChecked,onChange:e.onChange,disabled:e.props.disabled,onFocus:e._onFocus,onBlur:e._onBlur}),a.a.createElement("span",{className:h.a.poCheckboxSpan},"Draw Geometry"))},e.onChange=function(t){if("undefined"!=typeof window.parent.chrome){var n=t.target.checked,o={action:n?"DrawGeometry":"DisableDraw",data:e.props.args.data,uniqueId:e.props.args.uniqueId,options:e.props.args.options},a=JSON.stringify(o);window.parent.chrome.webview.postMessage(a),e.setState((function(e){return Object(r.a)(Object(r.a)({},e),{},{action:o.action,data:o.data,uniqueId:o.uniqueId,options:o.options,isChecked:n})}),(function(){return d.a.setComponentValue(o.data)})),console.log("JSON string sent!")}else console.log("Webview2 is not running...")},e._onFocus=function(){e.setState({isFocused:!0})},e._onBlur=function(){e.setState({isFocused:!1})},e}return Object(i.a)(n)}(d.b),f=Object(d.c)(m);s.a.render(a.a.createElement(a.a.StrictMode,null,a.a.createElement(f,null)),document.getElementById("root"))}},[[18,1,2]]]);
//# sourceMappingURL=main.4c388a94.chunk.js.map