self.__precacheManifest = (self.__precacheManifest || []).concat([
  {
    "revision": "fa18223a96ec1472303b89a75236c927",
    "url": "./index.html"
  },
  {
    "revision": "208d35235731dba57b9e",
    "url": "./static/css/main.33c720eb.chunk.css"
  },
  {
    "revision": "12f2b0485f6cecadfae4",
    "url": "./static/js/2.aa14d6ac.chunk.js"
  },
  {
    "revision": "3fc7fb5bfeeec1534560a2c962e360a7",
    "url": "./static/js/2.aa14d6ac.chunk.js.LICENSE.txt"
  },
  {
    "revision": "208d35235731dba57b9e",
    "url": "./static/js/main.b96db355.chunk.js"
  },
  {
    "revision": "7c26bca7e16783d14d15",
    "url": "./static/js/runtime-main.11ec9aca.js"
  }
]);